@@ -8,6 +8,7 @@ from django.utils.http import urlsafe_base64_encode
 from foqus.customers import *
 from foqus.commons import count_product, get_count_product_validation, get_payment_details_cms_shopify, get_valid_post,\
     replace_special_caractere, shopify_data_and_train
+from foqus.payments import p_fwd__stripe_payment
 from foqus.request_api import *
 
 from time import strftime, gmtime
@@ -1151,35 +1152,6 @@ def save_client_reviews(customer_name, customer_type, project_name, review, url_
     return response
 
 
-def payment_status(customer_name, customer_type):
-    pay_result = get_client_payment_status(customer_name, customer_type)
-    if pay_result:
-        response = {
-            'choosed_plan': pay_result[5],
-            'payment': {
-                'total': round(float(pay_result[9]), 2),
-                'payment_date': datetime.datetime.timestamp(pay_result[11]),
-                'payment_methode': pay_result[4],
-                'currency': pay_result[7],
-                'status': pay_result[8],
-                'transction_id': pay_result[6] if pay_result[6] else ""
-            }
-        }
-    else:
-        response = {
-            'choosed_plan': '',
-            'payment': {
-                'total': 0.00,
-                'payment_date': '',
-                'payment_methode': '',
-                'currency': 'eur',
-                'status': 0,
-                'transction_id': ''
-            }
-        }
-    return response
-
-
 def historic_users_management_customer():
     response = db.get__historic_users_management()
     result = []
@@ -1443,29 +1415,6 @@ def get_connected_customer_info(customer_email):
     return result
 
 
-def get_connected_customer_cms_info(customer_name, customer_type, cms):
-    result = db.get_cms_details_for_client(CMS_TABLE, customer_name, customer_type, cms)
-    if result:
-        response = {
-            'customer_name': result[1],
-            'customer_type': result[2],
-            'url_cms': result[5],
-            'access_token': result[6],
-            'cms_type': result[4],
-            'project_name': result[3],
-            'url_confirmation': result[7]}
-    else:
-        response = {
-            'customer_name': customer_name,
-            'customer_type': customer_type,
-            'url_cms': '',
-            'access_token': '',
-            'cms_type': cms,
-            'project_name': '',
-            'url_confirmation': ''}
-    return response
-
-
 def delete_user_data(customer_name, customer_type):
     tables_to_delete_from = [CMS_TABLE, STATUS_PROJECT_TABLE,
                              PAYMENT_TABLE, REVIEW_TABLE, HISTORY_SEARCH_TABLE, PAYMENT_INFO]
@@ -1518,4 +1467,215 @@ def delete_user_data_from_email(customer_email):
                 return delete_user_data(customer_name[0], customer_type[0])
 
     else:
-        return False
\ No newline at end of file
+        return False
+
+
+def save_payment_info(customer, customer_type, name, address, zipcode, country, city):
+    db.insert_or_update_payment_info(PAYMENT_INFO, customer, customer_type, name, address, zipcode, country, city)
+    return True
+
+
+def shopify_payment_billing(customer_name, customer_type, customer_email, url_cms, token_cms, plan):
+    from foqus.commons import get_api_version_shopify
+    from currency_converter import CurrencyConverter
+
+    c = CurrencyConverter()
+    headers = {
+        "X-Shopify-Access-Token": token_cms,
+        "Content-Type": "application/json"
+    }
+    # Delete active payment
+    api_version = get_api_version_shopify()
+    previous_payment = False
+    try:
+        payment_client = db.get_client_payment(customer_name, customer_type)
+        if payment_client != ():
+            previous_payment = True
+            payment_endpoint = "/admin/api/%s/recurring_application_charges/%s.json" % (api_version, payment_client[6])
+            get_payment_shopify_status = requests.get("https://{0}{1}".format(url_cms, payment_endpoint),
+                                                      headers=headers)
+            if get_payment_shopify_status.status_code == 200:
+                response_status = json.loads(get_payment_shopify_status.text)
+                if response_status.get('recurring_application_charge', {}).get('status', '') == 'active':
+                    delete_endpoint = "/admin/api/%s/recurring_application_charges/%s.json" \
+                                      % (api_version, payment_client[6])
+                    response_delete = requests.delete("https://{0}{1}".format(url_cms, delete_endpoint),
+                                                      headers=headers)
+                    if response_delete.status_code == 200:
+                        logger.info("========>payment deleted %s " % payment_client[6])
+        else:
+            previous_payment = False
+    except Exception as e:
+        logger.error("Exception deleting old payment %s for client %s %s " % (e, customer_name, customer_type))
+    if plan == 'STANDARD':
+        price = 99.0
+    elif plan == 'PREMIUM':
+        price = 299.0
+    else:
+        price = 499.0
+    price_dollar = round(c.convert(price, 'EUR', 'USD'))
+    endpoint = "/admin/api/%s/recurring_application_charges.json" % api_version
+    json_post = {
+        "recurring_application_charge": {
+            "name": plan,
+            "price": price_dollar,
+            "return_url": "https://foqus-shopify.azurewebsites.net/index"
+        }}
+
+    if LOCAL:
+        json_post['recurring_application_charge']['test'] = 'true'
+        json_post['recurring_application_charge']['trial_days'] = 1000
+    if not previous_payment:
+        json_post['recurring_application_charge']['trial_days'] = 30
+        total = price * 11
+    else:
+        total = price * 12
+    logger.info('===========> json to post %s total to pay %s' % (json.dumps(json_post), total))
+    charge_shopify_api = requests.post("https://{0}{1}".format(url_cms, endpoint), headers=headers, json=json_post)
+    if charge_shopify_api.status_code == 201:
+        response = json.loads(charge_shopify_api.text)
+        transaction_id = response.get('recurring_application_charge', {}).get('id', None)
+        url_confirmation = response.get('recurring_application_charge', {}).get('confirmation_url', '')
+        logger.info("====>recurring_application_charge_signup_url_confirmation %s " % transaction_id)
+        date = datetime.datetime.today().strftime("%Y-%m-%d %H:%M:%S")
+        db.update_client_payement(customer_name, customer_type, date, plan, 0, 'paypal', total)
+        db.update_transction_id(customer_name, customer_type, str(transaction_id), plan, date, 'paypal')
+        db.update_url_confirmation(customer_name, customer_type, 'shopify', url_cms, token_cms, url_confirmation)
+        return url_confirmation
+    else:
+        try:
+            first_name = db.get_profile(DATABASE_USERS_MANAGEMENT_TABLE_NAME, customer_email)[9]
+            logger.info("start sending email for informing_client_about_problem_shopify_payment  ...")
+            server = smtplib.SMTP(SMTP_HOST, 587)
+            server.login(SMTP_USERNAME, SMTP_PASSWORD)
+            fromaddr = "FOQUS <hello@foqus.ai>"
+            toaddr = customer_email
+            msg = MIMEMultipart()
+            msg['From'] = fromaddr
+            msg['To'] = toaddr
+            msg['Subject'] = 'Mettre à jour votre payement '
+            html_file = codecs.open(PATH_EMAIL_PROBLEM_SHOPIFY_PAYMENT, 'r')
+            payement_url = DOMAIN + 'payement/'
+            html = ((str(html_file.read()).replace("#first_name", first_name)).replace("#payement_url", payement_url))
+            part2 = MIMEText(html, 'html')
+            msg.attach(part2)
+            text = msg.as_string()
+            server.sendmail(fromaddr, toaddr, text)
+            logger.info("End of sending inscription email to client %s" % customer_email)
+        except Exception as e:
+            logger.info("exception in sending email ..." + str(e))
+        return ''
+
+
+def payment_status(customer_name, customer_type):
+    pay_result = get_client_payment_status(customer_name, customer_type)
+    address = db.get_client_adress(PAYMENT_INFO, customer_name, customer_type)
+    if address:
+        client_address = address[4] + " " + address[7] + ', ' + address[5] + " " + address[6]
+    else:
+        client_address = ""
+
+    plan_details = db.get_plan_form_name(pay_result[5])
+    if pay_result:
+        response = {
+            'choosed_plan': pay_result[5],
+            'plan_details': {
+                'max_post': plan_details[5],
+                'image_products': plan_details[4],
+                'total_payment': float(plan_details[3])},
+            'payment': {
+                'total': round(float(pay_result[9]), 2),
+                'payment_date': datetime.datetime.timestamp(pay_result[11]),
+                'payment_methode': pay_result[4],
+                'currency': pay_result[7],
+                'status': pay_result[8],
+                'transction_id': pay_result[6] if pay_result[6] else "",
+                'payment_address': client_address
+            }
+        }
+    else:
+        response = {
+            'choosed_plan': '',
+            'plan_details': {
+                'max_post': plan_details[5],
+                'image_products': plan_details[4],
+                'total_payment': float(plan_details[3])},
+            'payment': {
+                'total': 0.00,
+                'payment_date': '',
+                'payment_methode': '',
+                'currency': 'eur',
+                'status': 0,
+                'transction_id': '',
+                'payment_address': client_address
+            }
+        }
+    return response
+
+
+def payment_client(customer, customer_type, email,  plan_name, tva, methode_payment, payment_id=None, payer_id=None,
+                   stripe_token=None):
+    payment = db.get_client_payment(customer, customer_type)
+    if methode_payment == 'stripe':
+        date = datetime.datetime.today().strftime("%Y-%m-%d %H:%M:%S")
+        plan = db.get_plan_form_name(plan_name)
+        month_pay = (int(plan[3]) / 12)
+        to_pay = month_pay + (month_pay * float(tva))
+        total = to_pay * 11
+        db.update_client_payement(customer, customer_type, date, plan_name, 1, 'stripe', total)
+
+        logger.info(
+            '->STRIPETOKEN<- stripe token %s for client %s ' % (
+                stripe_token, email))
+        stripe_error = p_fwd__stripe_payment(payment, stripe_token,
+                                             float(str(total).replace(',', '.')), customer,
+                                             customer_type, plan_name, email)
+        from datetime import date
+        period_for_client = date(int(datetime.datetime.today().strftime("%Y")),
+                                 int(datetime.datetime.today().strftime("%m")),
+                                 int(datetime.datetime.today().strftime("%d"))) - \
+                            date(int(payment[3].strftime("%Y")), int(payment[3].strftime("%m")),
+                                 int(payment[3].strftime("%d")))
+        period_in_hours = (365 - int(period_for_client.days)) * 24
+        create_or_update_user_apikey(user=customer, period_in_hours=period_in_hours)
+        db.update_date_payment(customer, customer_type, datetime.datetime.today().strftime("%Y-%m-%d"))
+        if stripe_error:
+            logger.error("Errrror in payment the error is %s" % stripe_error)
+            return 0
+        else:
+            return 1
+    elif methode_payment == 'paypal':
+        date = datetime.datetime.today().strftime("%Y-%m-%d %H:%M:%S")
+        plan = db.get_plan_form_name(plan_name)
+        month_pay = (int(plan[3]) / 12)
+        to_pay = month_pay + (month_pay * float(tva))
+        total = to_pay * 11
+        db.update_client_payement(customer, customer_type, date, plan_name, 1, 'paypal', total)
+        db.update_transction_id(customer, customer_type, payment_id, plan_name, date, 'paypal')
+        db.update_customer_id(payment[1], payment[2], payer_id, payment[5], 'paypal')
+        from datetime import date
+        period_for_client = date(int(datetime.datetime.today().strftime("%Y")),
+                                 int(datetime.datetime.today().strftime("%m")),
+                                 int(datetime.datetime.today().strftime("%d"))) - \
+                            date(int(payment[3].strftime("%Y")), int(payment[3].strftime("%m")),
+                                 int(payment[3].strftime("%d")))
+        period_in_hours = (365 - int(period_for_client.days)) * 24
+        create_or_update_user_apikey(user=customer, period_in_hours=period_in_hours)
+        db.update_date_payment(customer, customer_type, datetime.datetime.today().strftime("%Y-%m-%d"))
+        return 1
+
+
+def get_connected_customer_cms_info(customer_name, customer_type, cms):
+    result = db.get_cms_details_for_client(CMS_TABLE, customer_name, customer_type, cms)
+    if result:
+        response = {
+            'customer_name': result[1],
+            'customer_type': result[2],
+            'url_cms': result[5],
+            'access_token': result[6],
+            'cms_type': result[4],
+            'project_name': result[3],
+            'url_confirmation': result[7]}
+    else:
+        response = {}
+    return response
\ No newline at end of file
