@@ -1,23 +1,25 @@
 #! /usr/bin/python
 # -*- coding: utf-8 -*-
-from urllib.parse import urlparse
-from six.moves import http_client
-import mimetypes
-import shutil
-from foqus.pipline_cutomise import *
-import imghdr
-
-from foqus.commons import resize_images, download
-
-from foqus.mqueue import *
+from foqus.commons import download
 from foqus.customers import *
-from foqus.request_api import *
+from foqus.pipline_cutomise import *
+from foqus.request_api import APIFoqus
+
+from six.moves import http_client
+
+from urllib.parse import urlparse
 from urllib.request import urlopen
+
+import imghdr
+import mimetypes
 import tensorflow as tf
+import requests
+import shutil
 import xlrd
 
 api = APIFoqus()
 
+
 def load_labels(label_file):
     if '://' in label_file:
         response = urlopen(label_file)
@@ -92,19 +94,19 @@ def checkUrl(url):
 
 
 def is_url_image(image_url):
-   image_formats = ("image/png", "image/jpeg", "image/jpg", "binary/octet-stream")
-   r = requests.head(image_url)
-   if r.headers["content-type"] not in image_formats:
-       mimetype, encoding = mimetypes.guess_type(image_url)
-       return (mimetype and mimetype.startswith('image'))
-   else:
-       return True
+    image_formats = ("image/png", "image/jpeg", "image/jpg", "binary/octet-stream")
+    r = requests.head(image_url)
+    if r.headers["content-type"] not in image_formats:
+        mimetype, encoding = mimetypes.guess_type(image_url)
+        return mimetype and mimetype.startswith('image')
+    else:
+        return True
 
 
 def image_extension(image_url):
     r = requests.head(image_url)
-    if (r.headers["content-type"]):
-        return (r.headers["content-type"].split('/')[1])
+    if r.headers["content-type"]:
+        return r.headers["content-type"].split('/')[1]
     else:
         return image_url.split('.')[-1]
 
@@ -122,6 +124,7 @@ def max_nb_images(path):
         list_nbrs.append(len(os.listdir(str(path) + "/" + str(j))))
     return max(list_nbrs)
 
+
 def verif_folder_less_twenty(path):
     image_ext = ['.jpg', '.png', '.jpeg', '.JPG', '.PNG', '.JPEG']
     folder_less_20 = []
@@ -155,7 +158,6 @@ def generate_more_images(training_path, folders, max_nb):
     logger.info("The images increase is done successfully")
 
 
-
 def read_tensor_from_image_file(file_name, input_height=299, input_width=299, input_mean=0, input_std=255):
     input_name = "file_reader"
     output_name = "normalized"
@@ -180,7 +182,7 @@ def read_tensor_from_image_file(file_name, input_height=299, input_width=299, in
     return result
 
 
-def fill_prediction_table(path_file_Final,customer_type, customer_name, customer_universe):
+def fill_prediction_table(path_file_Final, customer_type, customer_name, customer_universe):
     table_name = "predict_" + customer_type + '_' + customer_name + '_' + customer_universe
     db.create_prediction_table(table_name)
     workbook = xlrd.open_workbook(path_file_Final)
@@ -249,11 +251,10 @@ def generate_similarity_vector(customer_name="vector", customer_type='vector', p
 
 
 def text_training_retrieve_json(excel_path, customer_name, customer_type, customer_universe, project_name):
-    send_email_when_training_started(customer_name, project_name, 'classification', 'Apprentissage lancé!')
+    send_email_when_training_started(customer_name, project_name, 'classification', 'Training started')
     if project_name:
         operation = 'training_classification'
     else:
         operation = 'training_text_detection'
 
-    api.apipost(operation, customer_name, customer_type, project_name, excel_path,
-                               customer_universe)
\ No newline at end of file
+    api.apipost(operation, customer_name, customer_type, project_name, excel_path, customer_universe)
\ No newline at end of file
